@@ -28,7 +28,6 @@
  *   NV-CONTROL -> event -> glib -> CtkEvent -> signal -> GUI
  */
 
-
 #include <string.h>
 
 #include <gtk/gtk.h>
@@ -135,7 +134,6 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_CONNECTED_DISPLAYS);
     MAKE_SIGNAL(NV_CTRL_ENABLED_DISPLAYS);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK);
-    MAKE_SIGNAL(NV_CTRL_FRAMELOCK_MASTER);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK_POLARITY);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK_SYNC_DELAY);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK_SYNC_INTERVAL);
@@ -177,11 +175,8 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_IMAGE_SETTINGS);
     MAKE_SIGNAL(NV_CTRL_XINERAMA_STEREO);
     MAKE_SIGNAL(NV_CTRL_BUS_RATE);
-    MAKE_SIGNAL(NV_CTRL_SHOW_SLI_VISUAL_INDICATOR);
     MAKE_SIGNAL(NV_CTRL_XV_SYNC_TO_DISPLAY);
     MAKE_SIGNAL(NV_CTRL_ASSOCIATED_DISPLAY_DEVICES);
-    MAKE_SIGNAL(NV_CTRL_FRAMELOCK_SLAVES);
-    MAKE_SIGNAL(NV_CTRL_FRAMELOCK_MASTERABLE);
     MAKE_SIGNAL(NV_CTRL_PROBE_DISPLAYS);
     MAKE_SIGNAL(NV_CTRL_REFRESH_RATE);
     MAKE_SIGNAL(NV_CTRL_INITIAL_PIXMAP_PLACEMENT);
@@ -212,7 +207,6 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_NOTEBOOK_DISPLAY_CHANGE_LID_EVENT);
     MAKE_SIGNAL(NV_CTRL_MODE_SET_EVENT);
     MAKE_SIGNAL(NV_CTRL_OPENGL_AA_LINE_GAMMA_VALUE);
-    MAKE_SIGNAL(NV_CTRL_FRAMELOCK_SLAVEABLE);
     MAKE_SIGNAL(NV_CTRL_DISPLAYPORT_LINK_RATE);
     MAKE_SIGNAL(NV_CTRL_STEREO_EYES_EXCHANGE);
     MAKE_SIGNAL(NV_CTRL_NO_SCANOUT);
@@ -248,7 +242,6 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_THERMAL_SENSOR_READING);
     MAKE_SIGNAL(NV_CTRL_THERMAL_SENSOR_PROVIDER);
     MAKE_SIGNAL(NV_CTRL_THERMAL_SENSOR_TARGET);
-    MAKE_SIGNAL(NV_CTRL_SHOW_MULTIGPU_VISUAL_INDICATOR);
     MAKE_SIGNAL(NV_CTRL_GPU_CURRENT_PROCESSOR_CLOCK_FREQS);
     MAKE_SIGNAL(NV_CTRL_GPU_PCIE_MAX_LINK_SPEED);
     MAKE_SIGNAL(NV_CTRL_3D_VISION_PRO_TRANSCEIVER_CHANNEL);
@@ -273,7 +266,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_REBOOT);
     MAKE_SIGNAL(NV_CTRL_DPY_HDMI_3D);
     MAKE_SIGNAL(NV_CTRL_BASE_MOSAIC);
-    MAKE_SIGNAL(NV_CTRL_MULTIGPU_MASTER_POSSIBLE);
+    MAKE_SIGNAL(NV_CTRL_MULTIGPU_PRIMARY_POSSIBLE);
     MAKE_SIGNAL(NV_CTRL_GPU_POWER_MIZER_DEFAULT_MODE);
     MAKE_SIGNAL(NV_CTRL_XV_SYNC_TO_DISPLAY_ID);
     MAKE_SIGNAL(NV_CTRL_CURRENT_XV_SYNC_TO_DISPLAY_ID);
@@ -302,6 +295,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_DISPLAY_VRR_MODE);
     MAKE_SIGNAL(NV_CTRL_DISPLAY_VRR_MIN_REFRESH_RATE);
     MAKE_SIGNAL(NV_CTRL_DISPLAY_VRR_ENABLED);
+    MAKE_SIGNAL(NV_CTRL_PLATFORM_POWER_MODE);
 #undef MAKE_SIGNAL
 
     /*
@@ -311,7 +305,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
      * knows about.
      */
 
-#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_GPU_MAX_OPERATING_THRESHOLD
+#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_PLATFORM_CURRENT_POWER_MODE
 #warning "There are attributes that do not emit signals!"
 #endif
 
